@@ -258,14 +258,14 @@ def plane_basis_from_normal(plane_normal):
     return x_axis, y_axis
 
 
-def random_vector(random_state=np.random.RandomState(0), n=3):
+def random_vector(rng=np.random.RandomState(0), n=3, random_state=None):
     r"""Generate an nd vector with normally distributed components.
 
     Each component will be sampled from :math:`\mathcal{N}(\mu=0, \sigma=1)`.
 
     Parameters
     ----------
-    random_state : np.random.RandomState, optional (default: random seed 0)
+    rng : np.random.Generator, optional (default: random seed 0)
         Random number generator
 
     n : int, optional (default: 3)
@@ -276,10 +276,15 @@ def random_vector(random_state=np.random.RandomState(0), n=3):
     v : array, shape (n,)
         Random vector
     """
-    return random_state.randn(n)
+    if random_state is not None:  # pragma: no cover
+        warnings.warn(
+            "The random_state argument is deprecated. Use rng.",
+            DeprecationWarning)
+        rng = random_state
+    return rng.standard_normal(n)
 
 
-def random_axis_angle(random_state=np.random.RandomState(0)):
+def random_axis_angle(rng=np.random.RandomState(0), random_state=None):
     r"""Generate random axis-angle.
 
     The angle will be sampled uniformly from the interval :math:`[0, \pi)`
@@ -289,7 +294,7 @@ def random_axis_angle(random_state=np.random.RandomState(0)):
 
     Parameters
     ----------
-    random_state : np.random.RandomState, optional (default: random seed 0)
+    rng : np.random.Generator, optional (default: random seed 0)
         Random number generator
 
     Returns
@@ -297,13 +302,18 @@ def random_axis_angle(random_state=np.random.RandomState(0)):
     a : array, shape (4,)
         Axis of rotation and rotation angle: (x, y, z, angle)
     """
-    angle = np.pi * random_state.rand()
+    if random_state is not None:  # pragma: no cover
+        warnings.warn(
+            "The random_state argument is deprecated. Use rng.",
+            DeprecationWarning)
+        rng = random_state
+    angle = np.pi * rng.random()
     a = np.array([0, 0, 0, angle])
-    a[:3] = norm_vector(random_state.randn(3))
+    a[:3] = norm_vector(rng.standard_normal(3))
     return a
 
 
-def random_compact_axis_angle(random_state=np.random.RandomState(0)):
+def random_compact_axis_angle(rng=np.random.RandomState(0), random_state=None):
     r"""Generate random compact axis-angle.
 
     The angle will be sampled uniformly from the interval :math:`[0, \pi)`
@@ -313,7 +323,7 @@ def random_compact_axis_angle(random_state=np.random.RandomState(0)):
 
     Parameters
     ----------
-    random_state : np.random.RandomState, optional (default: random seed 0)
+    rng : np.random.Generator, optional (default: random seed 0)
         Random number generator
 
     Returns
@@ -321,16 +331,21 @@ def random_compact_axis_angle(random_state=np.random.RandomState(0)):
     a : array, shape (3,)
         Axis of rotation and rotation angle: angle * (x, y, z)
     """
-    a = random_axis_angle(random_state)
+    if random_state is not None:  # pragma: no cover
+        warnings.warn(
+            "The random_state argument is deprecated. Use rng.",
+            DeprecationWarning)
+        rng = random_state
+    a = random_axis_angle(rng)
     return a[:3] * a[3]
 
 
-def random_quaternion(random_state=np.random.RandomState(0)):
+def random_quaternion(rng=np.random.RandomState(0), random_state=None):
     """Generate random quaternion.
 
     Parameters
     ----------
-    random_state : np.random.RandomState, optional (default: random seed 0)
+    rng : np.random.Generator, optional (default: random seed 0)
         Random number generator
 
     Returns
@@ -338,7 +353,12 @@ def random_quaternion(random_state=np.random.RandomState(0)):
     q : array, shape (4,)
         Unit quaternion to represent rotation: (w, x, y, z)
     """
-    return norm_vector(random_state.randn(4))
+    if random_state is not None:  # pragma: no cover
+        warnings.warn(
+            "The random_state argument is deprecated. Use rng.",
+            DeprecationWarning)
+        rng = random_state
+    return norm_vector(rng.standard_normal(4))
 
 
 def check_skew_symmetric_matrix(V, tolerance=1e-6, strict_check=True):
