@@ -4,6 +4,7 @@ See :doc:`transform_manager` for more information.
 """
 import os
 import numpy as np
+import warnings
 from bs4 import BeautifulSoup
 from .transform_manager import TransformManager
 from .transformations import transform_from, concat
@@ -70,8 +71,8 @@ class UrdfTransformManager(TransformManager):
             Lower and upper joint angle limit
 
         joint_type : str, optional (default: 'revolute')
-            Joint type: revolute or prismatic (continuous is the same as
-            revolute)
+            Joint type: revolute, prismatic, or fixed (continuous is the same
+            as revolute)
         """
         self.add_transform(from_frame, to_frame, child2parent)
         self._joints[joint_name] = (
@@ -108,11 +109,14 @@ class UrdfTransformManager(TransformManager):
                 np.hstack((axis, (value,))))
             joint2A = transform_from(
                 joint_rotation, np.zeros(3), strict_check=self.strict_check)
-        else:
-            assert joint_type == "prismatic"
+        elif joint_type == "prismatic":
             joint_offset = value * axis
             joint2A = transform_from(
                 np.eye(3), joint_offset, strict_check=self.strict_check)
+        else:
+            assert joint_type == "fixed"
+            warnings.warn("Trying to set a fixed joint")
+            return
         self.add_transform(from_frame, to_frame, concat(
             joint2A, child2parent, strict_check=self.strict_check,
             check=self.check))
@@ -641,7 +645,10 @@ def _add_joints(tm, joints):
                 "prismatic")
         else:
             assert joint.joint_type == "fixed"
-            tm.add_transform(joint.child, joint.parent, joint.child2parent)
+            tm.add_joint(
+                joint.joint_name, joint.child, joint.parent,
+                joint.child2parent, joint.joint_axis, (0.0, 0.0),
+                "fixed")
 
 
 class Link(object):
